@@ -1,10 +1,12 @@
 var classlibcamera_1_1SwStatsCpu =
 [
+    [ "SwStatsCpu", "classlibcamera_1_1SwStatsCpu.html#a87e66665f27b00b2414921766bb5ad0d", null ],
     [ "configure", "classlibcamera_1_1SwStatsCpu.html#a2fb7c76cb850a5638bd48eb7a697dede", null ],
     [ "finishFrame", "classlibcamera_1_1SwStatsCpu.html#a322830c43185aefeeaebe7773fa1f81b", null ],
     [ "getStatsFD", "classlibcamera_1_1SwStatsCpu.html#a07f805ae47a24bac031894555b2c4b88", null ],
     [ "isValid", "classlibcamera_1_1SwStatsCpu.html#aba238537c87ae40f0e78d27d0b09dcac", null ],
     [ "patternSize", "classlibcamera_1_1SwStatsCpu.html#acc4efd5377f6c89d235a37d7bd066505", null ],
+    [ "processFrame", "classlibcamera_1_1SwStatsCpu.html#abc33927e094d5ce496f5f5fef29182d3", null ],
     [ "processLine0", "classlibcamera_1_1SwStatsCpu.html#a11971d578ea1eb48ac48bc6277e91e2d", null ],
     [ "processLine2", "classlibcamera_1_1SwStatsCpu.html#a13bc80be93134fdf3c2375b240a1c900", null ],
     [ "setWindow", "classlibcamera_1_1SwStatsCpu.html#a553b4593d4397d2a2c9567a59708c7d9", null ],
