@@ -1,5 +1,64 @@
 var NAVTREEINDEX4 =
 {
+"classlibcamera_1_1EventNotifier.html#a83550c524a9bcc0ea582e876ca43c04d":[6,0,0,7,4],
+"classlibcamera_1_1EventNotifier.html#a83550c524a9bcc0ea582e876ca43c04d":[7,0,0,6,4],
+"classlibcamera_1_1EventNotifier.html#ac8abf83fcaebd9ec6595e9ea7f426c8e":[6,0,0,7,1],
+"classlibcamera_1_1EventNotifier.html#ac8abf83fcaebd9ec6595e9ea7f426c8e":[7,0,0,6,1],
+"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238":[6,0,0,7,0],
+"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238":[7,0,0,6,0],
+"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238a0def601bcb4442f07c3f772875fc8da4":[6,0,0,7,0,2],
+"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238a0def601bcb4442f07c3f772875fc8da4":[7,0,0,6,0,2],
+"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238a3291c8605f14dd5f7e37b1b45dca76e9":[6,0,0,7,0,1],
+"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238a3291c8605f14dd5f7e37b1b45dca76e9":[7,0,0,6,0,1],
+"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238acb9c83f52b00cc7cb91bb6a5235b91f6":[6,0,0,7,0,0],
+"classlibcamera_1_1EventNotifier.html#adceea4fbe37e9a3833dce6e258e35238acb9c83f52b00cc7cb91bb6a5235b91f6":[7,0,0,6,0,0],
+"classlibcamera_1_1EventNotifier.html#afd2af0fa47b553e9333f9feffb08449a":[6,0,0,7,7],
+"classlibcamera_1_1EventNotifier.html#afd2af0fa47b553e9333f9feffb08449a":[7,0,0,6,7],
+"classlibcamera_1_1Extensible.html":[6,0,0,4],
+"classlibcamera_1_1Extensible.html":[7,0,0,3],
+"classlibcamera_1_1Extensible.html#a524dff9d63a486fc4cfc2d0d1ce07711":[6,0,0,4,3],
+"classlibcamera_1_1Extensible.html#a524dff9d63a486fc4cfc2d0d1ce07711":[7,0,0,3,3],
+"classlibcamera_1_1Extensible.html#a7a31dab4cfefc741263bd8407bd29b6f":[6,0,0,4,2],
+"classlibcamera_1_1Extensible.html#a7a31dab4cfefc741263bd8407bd29b6f":[7,0,0,3,2],
+"classlibcamera_1_1Extensible.html#afb1c6e39d8fe4fbeab1cbbbe65517f4c":[6,0,0,4,1],
+"classlibcamera_1_1Extensible.html#afb1c6e39d8fe4fbeab1cbbbe65517f4c":[7,0,0,3,1],
+"classlibcamera_1_1Extensible_1_1Private.html":[6,0,0,4,0],
+"classlibcamera_1_1Extensible_1_1Private.html":[7,0,0,3,0],
+"classlibcamera_1_1Extensible_1_1Private.html#a58af2c3e5a3ff3301df0a10ea282c766":[6,0,0,4,0,0],
+"classlibcamera_1_1Extensible_1_1Private.html#a58af2c3e5a3ff3301df0a10ea282c766":[7,0,0,3,0,0],
+"classlibcamera_1_1Fence.html":[6,0,0,37],
+"classlibcamera_1_1Fence.html":[7,0,0,36],
+"classlibcamera_1_1Fence.html#a1b435a69df48ed28e888ef82f1a2d15a":[6,0,0,37,2],
+"classlibcamera_1_1Fence.html#a1b435a69df48ed28e888ef82f1a2d15a":[7,0,0,36,2],
+"classlibcamera_1_1Fence.html#a5beebc2b3cd811bdea441b3d848e3419":[6,0,0,37,3],
+"classlibcamera_1_1Fence.html#a5beebc2b3cd811bdea441b3d848e3419":[7,0,0,36,3],
+"classlibcamera_1_1Fence.html#aaa3009c674cee1c2172e6d481f4540b8":[6,0,0,37,1],
+"classlibcamera_1_1Fence.html#aaa3009c674cee1c2172e6d481f4540b8":[7,0,0,36,1],
+"classlibcamera_1_1Fence.html#ab84dac1ce57f0370012d6b278a99325a":[6,0,0,37,0],
+"classlibcamera_1_1Fence.html#ab84dac1ce57f0370012d6b278a99325a":[7,0,0,36,0],
+"classlibcamera_1_1File.html":[6,0,0,8],
+"classlibcamera_1_1File.html":[7,0,0,7],
+"classlibcamera_1_1File.html#a128efbbcacb7cdaa1986ffc943e89ae0":[6,0,0,8,2],
+"classlibcamera_1_1File.html#a128efbbcacb7cdaa1986ffc943e89ae0":[7,0,0,7,2],
+"classlibcamera_1_1File.html#a128efbbcacb7cdaa1986ffc943e89ae0a44f0e1a448f14b3cfcae67338bdc04bb":[6,0,0,8,2,0],
+"classlibcamera_1_1File.html#a128efbbcacb7cdaa1986ffc943e89ae0a44f0e1a448f14b3cfcae67338bdc04bb":[7,0,0,7,2,0],
+"classlibcamera_1_1File.html#a128efbbcacb7cdaa1986ffc943e89ae0a47f9082fc380ca62d531096aa1d110f1":[6,0,0,8,2,1],
+"classlibcamera_1_1File.html#a128efbbcacb7cdaa1986ffc943e89ae0a47f9082fc380ca62d531096aa1d110f1":[7,0,0,7,2,1],
+"classlibcamera_1_1File.html#a17a868b3e07508e37463acbbd525e881":[6,0,0,8,8],
+"classlibcamera_1_1File.html#a17a868b3e07508e37463acbbd525e881":[7,0,0,7,8],
+"classlibcamera_1_1File.html#a387e2f92eb36a45aad031915ca90471a":[6,0,0,8,10],
+"classlibcamera_1_1File.html#a387e2f92eb36a45aad031915ca90471a":[7,0,0,7,10],
+"classlibcamera_1_1File.html#a41891c0fb18b11268b9367df43f99532":[6,0,0,8,9],
+"classlibcamera_1_1File.html#a41891c0fb18b11268b9367df43f99532":[7,0,0,7,9],
+"classlibcamera_1_1File.html#a51d5e31e1583c024674392b721fe81d7":[6,0,0,8,13],
+"classlibcamera_1_1File.html#a51d5e31e1583c024674392b721fe81d7":[7,0,0,7,13],
+"classlibcamera_1_1File.html#a596bea491fd1306082e462842559c929":[6,0,0,8,21],
+"classlibcamera_1_1File.html#a596bea491fd1306082e462842559c929":[7,0,0,7,21],
+"classlibcamera_1_1File.html#a62ad081ef9f239b476815bf855de08d7":[6,0,0,8,7],
+"classlibcamera_1_1File.html#a62ad081ef9f239b476815bf855de08d7":[7,0,0,7,7],
+"classlibcamera_1_1File.html#a6df7f0036263a0a04610e586e9e604cb":[6,0,0,8,3],
+"classlibcamera_1_1File.html#a6df7f0036263a0a04610e586e9e604cb":[7,0,0,7,3],
+"classlibcamera_1_1File.html#a6df7f0036263a0a04610e586e9e604cba131fb182a881796e7606ed6da27f1197":[6,0,0,8,3,1],
 "classlibcamera_1_1File.html#a6df7f0036263a0a04610e586e9e604cba131fb182a881796e7606ed6da27f1197":[7,0,0,7,3,1],
 "classlibcamera_1_1File.html#a6df7f0036263a0a04610e586e9e604cba53dfe5089ae9e65887cb0215cb0098f5":[6,0,0,8,3,2],
 "classlibcamera_1_1File.html#a6df7f0036263a0a04610e586e9e604cba53dfe5089ae9e65887cb0215cb0098f5":[7,0,0,7,3,2],
@@ -131,123 +190,64 @@ var NAVTREEINDEX4 =
 "classlibcamera_1_1FrameBuffer_1_1Private.html#ac2d68ef33ed61767fb533a7dc8672e28":[7,0,0,38,1,7],
 "classlibcamera_1_1FrameBuffer_1_1Private.html#ae18d68743f5e9d102cc3b639f9a5c6ad":[6,0,0,39,1,5],
 "classlibcamera_1_1FrameBuffer_1_1Private.html#ae18d68743f5e9d102cc3b639f9a5c6ad":[7,0,0,38,1,5],
-"classlibcamera_1_1GlobalConfiguration.html":[6,0,0,69],
-"classlibcamera_1_1GlobalConfiguration.html":[7,0,0,68],
-"classlibcamera_1_1GlobalConfiguration.html#a04297352674816b3b5cd8122db228ebd":[6,0,0,69,0],
-"classlibcamera_1_1GlobalConfiguration.html#a04297352674816b3b5cd8122db228ebd":[7,0,0,68,0],
-"classlibcamera_1_1GlobalConfiguration.html#a0dd99046b76c30ad19b0262c7ffba63e":[6,0,0,69,3],
-"classlibcamera_1_1GlobalConfiguration.html#a0dd99046b76c30ad19b0262c7ffba63e":[7,0,0,68,3],
-"classlibcamera_1_1GlobalConfiguration.html#a2f6d03527e6bc4b27da3289374b9e310":[6,0,0,69,1],
-"classlibcamera_1_1GlobalConfiguration.html#a2f6d03527e6bc4b27da3289374b9e310":[7,0,0,68,1],
-"classlibcamera_1_1GlobalConfiguration.html#a436214694d4f740e28234caaf432dc99":[6,0,0,69,7],
-"classlibcamera_1_1GlobalConfiguration.html#a436214694d4f740e28234caaf432dc99":[7,0,0,68,7],
-"classlibcamera_1_1GlobalConfiguration.html#a53e9b531b84f86a90f447d6c527ae2d9":[6,0,0,69,5],
-"classlibcamera_1_1GlobalConfiguration.html#a53e9b531b84f86a90f447d6c527ae2d9":[7,0,0,68,5],
-"classlibcamera_1_1GlobalConfiguration.html#a5c0b06a623cc40342836274096199e0f":[6,0,0,69,6],
-"classlibcamera_1_1GlobalConfiguration.html#a5c0b06a623cc40342836274096199e0f":[7,0,0,68,6],
-"classlibcamera_1_1GlobalConfiguration.html#a71c9f93f0d29a4941bb385dc6807801f":[6,0,0,69,2],
-"classlibcamera_1_1GlobalConfiguration.html#a71c9f93f0d29a4941bb385dc6807801f":[7,0,0,68,2],
-"classlibcamera_1_1GlobalConfiguration.html#a913eab5143dab42f59b31b8ca78b0b22":[6,0,0,69,4],
-"classlibcamera_1_1GlobalConfiguration.html#a913eab5143dab42f59b31b8ca78b0b22":[7,0,0,68,4],
-"classlibcamera_1_1IPADataSerializer.html":[6,0,0,70],
-"classlibcamera_1_1IPADataSerializer.html":[7,0,0,69],
-"classlibcamera_1_1IPAInterface.html":[6,0,0,115],
-"classlibcamera_1_1IPAInterface.html":[7,0,0,114],
-"classlibcamera_1_1IPAManager.html":[6,0,0,71],
-"classlibcamera_1_1IPAManager.html":[7,0,0,70],
-"classlibcamera_1_1IPAManager.html#aa1b2b4ec84cb0137fe3269f3eb1297b7":[6,0,0,71,0],
-"classlibcamera_1_1IPAManager.html#aa1b2b4ec84cb0137fe3269f3eb1297b7":[7,0,0,70,0],
-"classlibcamera_1_1IPAModule.html":[6,0,0,72],
-"classlibcamera_1_1IPAModule.html":[7,0,0,71],
-"classlibcamera_1_1IPAModule.html#a25eaa78c15705ddd7384516c1657745d":[6,0,0,72,2],
-"classlibcamera_1_1IPAModule.html#a25eaa78c15705ddd7384516c1657745d":[7,0,0,71,2],
-"classlibcamera_1_1IPAModule.html#a81b5a10c65b1aeef7218c1b4376ef837":[6,0,0,72,5],
-"classlibcamera_1_1IPAModule.html#a81b5a10c65b1aeef7218c1b4376ef837":[7,0,0,71,5],
-"classlibcamera_1_1IPAModule.html#a872ccac8bdf3c6ebae395354e4bf9695":[6,0,0,72,8],
-"classlibcamera_1_1IPAModule.html#a872ccac8bdf3c6ebae395354e4bf9695":[7,0,0,71,8],
-"classlibcamera_1_1IPAModule.html#a8a092bd638e35b4d3f4ac51f58fe4d51":[6,0,0,72,4],
-"classlibcamera_1_1IPAModule.html#a8a092bd638e35b4d3f4ac51f58fe4d51":[7,0,0,71,4],
-"classlibcamera_1_1IPAModule.html#abf5eccedd5356d382c1377eddcaf7d9c":[6,0,0,72,0],
-"classlibcamera_1_1IPAModule.html#abf5eccedd5356d382c1377eddcaf7d9c":[7,0,0,71,0],
-"classlibcamera_1_1IPAModule.html#ac4442f2b5ae1e04e0ea0341848707670":[6,0,0,72,7],
-"classlibcamera_1_1IPAModule.html#ac4442f2b5ae1e04e0ea0341848707670":[7,0,0,71,7],
-"classlibcamera_1_1IPAModule.html#aeff066789ce1cfd94e14169cdcd6c7c7":[6,0,0,72,6],
-"classlibcamera_1_1IPAModule.html#aeff066789ce1cfd94e14169cdcd6c7c7":[7,0,0,71,6],
-"classlibcamera_1_1IPAModule.html#af14705dc1eebb33518e8c3aacf3b7957":[6,0,0,72,3],
-"classlibcamera_1_1IPAModule.html#af14705dc1eebb33518e8c3aacf3b7957":[7,0,0,71,3],
-"classlibcamera_1_1IPAModule.html#af70448b68ca0f671376b4ca93e402e79":[6,0,0,72,1],
-"classlibcamera_1_1IPAModule.html#af70448b68ca0f671376b4ca93e402e79":[7,0,0,71,1],
-"classlibcamera_1_1IPAProxy.html":[6,0,0,73],
-"classlibcamera_1_1IPAProxy.html":[7,0,0,72],
-"classlibcamera_1_1IPAProxy.html#a4d55ecad4864e4366622c1b804d2088a":[6,0,0,73,3],
-"classlibcamera_1_1IPAProxy.html#a4d55ecad4864e4366622c1b804d2088a":[7,0,0,72,3],
-"classlibcamera_1_1IPAProxy.html#a65233b120ff57bd960121bc37f9d86b5":[6,0,0,73,2],
-"classlibcamera_1_1IPAProxy.html#a65233b120ff57bd960121bc37f9d86b5":[7,0,0,72,2],
-"classlibcamera_1_1IPAProxy.html#a8986755718582d7960faa96f24777e93":[6,0,0,73,1],
-"classlibcamera_1_1IPAProxy.html#a8986755718582d7960faa96f24777e93":[7,0,0,72,1],
-"classlibcamera_1_1IPAProxy.html#aa298816d19d6455f64f3456ccaa70a98":[6,0,0,73,4],
-"classlibcamera_1_1IPAProxy.html#aa298816d19d6455f64f3456ccaa70a98":[7,0,0,72,4],
-"classlibcamera_1_1IPAProxy.html#ab5aa3b74285a5f4301218f05dd4cff09":[6,0,0,73,5],
-"classlibcamera_1_1IPAProxy.html#ab5aa3b74285a5f4301218f05dd4cff09":[7,0,0,72,5],
-"classlibcamera_1_1IPAProxy.html#ae59a8a916c5e244be8bdd6860503886f":[6,0,0,73,0],
-"classlibcamera_1_1IPAProxy.html#ae59a8a916c5e244be8bdd6860503886f":[7,0,0,72,0],
-"classlibcamera_1_1IPAProxy.html#ae59a8a916c5e244be8bdd6860503886fa547f15ec7e7ee0b6e7983786b9794b70":[6,0,0,73,0,2],
-"classlibcamera_1_1IPAProxy.html#ae59a8a916c5e244be8bdd6860503886fa547f15ec7e7ee0b6e7983786b9794b70":[7,0,0,72,0,2],
-"classlibcamera_1_1IPAProxy.html#ae59a8a916c5e244be8bdd6860503886fa78854166050cb92cde770894115147b7":[6,0,0,73,0,0],
-"classlibcamera_1_1IPAProxy.html#ae59a8a916c5e244be8bdd6860503886fa78854166050cb92cde770894115147b7":[7,0,0,72,0,0],
-"classlibcamera_1_1IPAProxy.html#ae59a8a916c5e244be8bdd6860503886fa9878670e20d29e97ff098b069d50b0f0":[6,0,0,73,0,1],
-"classlibcamera_1_1IPAProxy.html#ae59a8a916c5e244be8bdd6860503886fa9878670e20d29e97ff098b069d50b0f0":[7,0,0,72,0,1],
-"classlibcamera_1_1IPAProxy.html#afb8f81b8f6955191147b8a9f13ec3c1a":[6,0,0,73,6],
-"classlibcamera_1_1IPAProxy.html#afb8f81b8f6955191147b8a9f13ec3c1a":[7,0,0,72,6],
-"classlibcamera_1_1IPCMessage.html":[6,0,0,74],
-"classlibcamera_1_1IPCMessage.html":[7,0,0,73],
-"classlibcamera_1_1IPCMessage.html#a18d5528b27ded668463f02217ff189d7":[6,0,0,74,1],
-"classlibcamera_1_1IPCMessage.html#a18d5528b27ded668463f02217ff189d7":[7,0,0,73,1],
-"classlibcamera_1_1IPCMessage.html#a18d9502a924db483ee1deffe37de8117":[6,0,0,74,11],
-"classlibcamera_1_1IPCMessage.html#a18d9502a924db483ee1deffe37de8117":[7,0,0,73,11],
-"classlibcamera_1_1IPCMessage.html#a4d2ff264e5f3f14eec239d7e40a01ef5":[6,0,0,74,8],
-"classlibcamera_1_1IPCMessage.html#a4d2ff264e5f3f14eec239d7e40a01ef5":[7,0,0,73,8],
-"classlibcamera_1_1IPCMessage.html#a58f44361e8352a80242371d426a79b38":[6,0,0,74,7],
-"classlibcamera_1_1IPCMessage.html#a58f44361e8352a80242371d426a79b38":[7,0,0,73,7],
-"classlibcamera_1_1IPCMessage.html#a6d71fee6f6d1f960d24e77cbf7304f80":[6,0,0,74,3],
-"classlibcamera_1_1IPCMessage.html#a6d71fee6f6d1f960d24e77cbf7304f80":[7,0,0,73,3],
-"classlibcamera_1_1IPCMessage.html#aac22ce8e978d33e8b55c2b79f4e1e61b":[6,0,0,74,4],
-"classlibcamera_1_1IPCMessage.html#aac22ce8e978d33e8b55c2b79f4e1e61b":[7,0,0,73,4],
-"classlibcamera_1_1IPCMessage.html#ad5ec86e5785c67d7c0b1d23a463cad15":[6,0,0,74,5],
-"classlibcamera_1_1IPCMessage.html#ad5ec86e5785c67d7c0b1d23a463cad15":[7,0,0,73,5],
-"classlibcamera_1_1IPCMessage.html#ae3df01d0c05418b40d88ef13d2e1b306":[6,0,0,74,9],
-"classlibcamera_1_1IPCMessage.html#ae3df01d0c05418b40d88ef13d2e1b306":[7,0,0,73,9],
-"classlibcamera_1_1IPCMessage.html#ae45c34c32b15f0de807cc5efd27a60ce":[6,0,0,74,2],
-"classlibcamera_1_1IPCMessage.html#ae45c34c32b15f0de807cc5efd27a60ce":[7,0,0,73,2],
-"classlibcamera_1_1IPCMessage.html#ae7dc062253a9960dd94b0b7f34df30e2":[6,0,0,74,6],
-"classlibcamera_1_1IPCMessage.html#ae7dc062253a9960dd94b0b7f34df30e2":[7,0,0,73,6],
-"classlibcamera_1_1IPCMessage.html#af827f6185ffafc963f5a7bcdc9a6abcb":[6,0,0,74,10],
-"classlibcamera_1_1IPCMessage.html#af827f6185ffafc963f5a7bcdc9a6abcb":[7,0,0,73,10],
-"classlibcamera_1_1IPCPipe.html":[6,0,0,75],
-"classlibcamera_1_1IPCPipe.html":[7,0,0,74],
-"classlibcamera_1_1IPCPipe.html#a2295cb66be1cbad98abb95cd602e0d2f":[6,0,0,75,2],
-"classlibcamera_1_1IPCPipe.html#a2295cb66be1cbad98abb95cd602e0d2f":[7,0,0,74,2],
-"classlibcamera_1_1IPCPipe.html#a250ca29858947ae7217f5816a62f424d":[6,0,0,75,5],
-"classlibcamera_1_1IPCPipe.html#a250ca29858947ae7217f5816a62f424d":[7,0,0,74,5],
-"classlibcamera_1_1IPCPipe.html#a290247bab6b803b392949dc04b2796ee":[6,0,0,75,0],
-"classlibcamera_1_1IPCPipe.html#a290247bab6b803b392949dc04b2796ee":[7,0,0,74,0],
-"classlibcamera_1_1IPCPipe.html#a2efdd118f95565f5f5dc059667e5cf79":[6,0,0,75,4],
-"classlibcamera_1_1IPCPipe.html#a2efdd118f95565f5f5dc059667e5cf79":[7,0,0,74,4],
-"classlibcamera_1_1IPCPipe.html#ab7704ab466f97540f0a00e055232cc98":[6,0,0,75,1],
-"classlibcamera_1_1IPCPipe.html#ab7704ab466f97540f0a00e055232cc98":[7,0,0,74,1],
-"classlibcamera_1_1IPCPipe.html#af5f01bded87e4a3d0c149376b5cbeda9":[6,0,0,75,3],
-"classlibcamera_1_1IPCPipe.html#af5f01bded87e4a3d0c149376b5cbeda9":[7,0,0,74,3],
-"classlibcamera_1_1IPCUnixSocket.html":[6,0,0,76],
-"classlibcamera_1_1IPCUnixSocket.html":[7,0,0,75],
-"classlibcamera_1_1IPCUnixSocket.html#a11995aca6423a568e6d1303dc80cd239":[6,0,0,76,5],
-"classlibcamera_1_1IPCUnixSocket.html#a11995aca6423a568e6d1303dc80cd239":[7,0,0,75,5],
-"classlibcamera_1_1IPCUnixSocket.html#a19b7f3e0fc40f7480c9218b17e5d9491":[6,0,0,76,7],
-"classlibcamera_1_1IPCUnixSocket.html#a19b7f3e0fc40f7480c9218b17e5d9491":[7,0,0,75,7],
-"classlibcamera_1_1IPCUnixSocket.html#a1f89e74d2780dbfb80b4cc94731d9af5":[6,0,0,76,6],
-"classlibcamera_1_1IPCUnixSocket.html#a1f89e74d2780dbfb80b4cc94731d9af5":[7,0,0,75,6],
-"classlibcamera_1_1IPCUnixSocket.html#a28e592b0ecd87a5397960f081b106c91":[6,0,0,76,4],
-"classlibcamera_1_1IPCUnixSocket.html#a28e592b0ecd87a5397960f081b106c91":[7,0,0,75,4],
-"classlibcamera_1_1IPCUnixSocket.html#a89dfc24daccd1cb7c39b165f9150dee1":[6,0,0,76,2],
-"classlibcamera_1_1IPCUnixSocket.html#a89dfc24daccd1cb7c39b165f9150dee1":[7,0,0,75,2],
-"classlibcamera_1_1IPCUnixSocket.html#a9c11dc2c41bc3e3047d66f37bd6f84a6":[6,0,0,76,1]
+"classlibcamera_1_1GlobalConfiguration.html":[6,0,0,71],
+"classlibcamera_1_1GlobalConfiguration.html":[7,0,0,70],
+"classlibcamera_1_1GlobalConfiguration.html#a04297352674816b3b5cd8122db228ebd":[6,0,0,71,0],
+"classlibcamera_1_1GlobalConfiguration.html#a04297352674816b3b5cd8122db228ebd":[7,0,0,70,0],
+"classlibcamera_1_1GlobalConfiguration.html#a0dd99046b76c30ad19b0262c7ffba63e":[6,0,0,71,3],
+"classlibcamera_1_1GlobalConfiguration.html#a0dd99046b76c30ad19b0262c7ffba63e":[7,0,0,70,3],
+"classlibcamera_1_1GlobalConfiguration.html#a2f6d03527e6bc4b27da3289374b9e310":[6,0,0,71,1],
+"classlibcamera_1_1GlobalConfiguration.html#a2f6d03527e6bc4b27da3289374b9e310":[7,0,0,70,1],
+"classlibcamera_1_1GlobalConfiguration.html#a436214694d4f740e28234caaf432dc99":[6,0,0,71,7],
+"classlibcamera_1_1GlobalConfiguration.html#a436214694d4f740e28234caaf432dc99":[7,0,0,70,7],
+"classlibcamera_1_1GlobalConfiguration.html#a53e9b531b84f86a90f447d6c527ae2d9":[6,0,0,71,5],
+"classlibcamera_1_1GlobalConfiguration.html#a53e9b531b84f86a90f447d6c527ae2d9":[7,0,0,70,5],
+"classlibcamera_1_1GlobalConfiguration.html#a5c0b06a623cc40342836274096199e0f":[6,0,0,71,6],
+"classlibcamera_1_1GlobalConfiguration.html#a5c0b06a623cc40342836274096199e0f":[7,0,0,70,6],
+"classlibcamera_1_1GlobalConfiguration.html#a71c9f93f0d29a4941bb385dc6807801f":[6,0,0,71,2],
+"classlibcamera_1_1GlobalConfiguration.html#a71c9f93f0d29a4941bb385dc6807801f":[7,0,0,70,2],
+"classlibcamera_1_1GlobalConfiguration.html#a913eab5143dab42f59b31b8ca78b0b22":[6,0,0,71,4],
+"classlibcamera_1_1GlobalConfiguration.html#a913eab5143dab42f59b31b8ca78b0b22":[7,0,0,70,4],
+"classlibcamera_1_1IPADataSerializer.html":[6,0,0,72],
+"classlibcamera_1_1IPADataSerializer.html":[7,0,0,71],
+"classlibcamera_1_1IPAInterface.html":[6,0,0,119],
+"classlibcamera_1_1IPAInterface.html":[7,0,0,118],
+"classlibcamera_1_1IPAManager.html":[6,0,0,73],
+"classlibcamera_1_1IPAManager.html":[7,0,0,72],
+"classlibcamera_1_1IPAManager.html#aa1b2b4ec84cb0137fe3269f3eb1297b7":[6,0,0,73,0],
+"classlibcamera_1_1IPAManager.html#aa1b2b4ec84cb0137fe3269f3eb1297b7":[7,0,0,72,0],
+"classlibcamera_1_1IPAModule.html":[6,0,0,74],
+"classlibcamera_1_1IPAModule.html":[7,0,0,73],
+"classlibcamera_1_1IPAModule.html#a25eaa78c15705ddd7384516c1657745d":[6,0,0,74,2],
+"classlibcamera_1_1IPAModule.html#a25eaa78c15705ddd7384516c1657745d":[7,0,0,73,2],
+"classlibcamera_1_1IPAModule.html#a81b5a10c65b1aeef7218c1b4376ef837":[6,0,0,74,5],
+"classlibcamera_1_1IPAModule.html#a81b5a10c65b1aeef7218c1b4376ef837":[7,0,0,73,5],
+"classlibcamera_1_1IPAModule.html#a872ccac8bdf3c6ebae395354e4bf9695":[6,0,0,74,8],
+"classlibcamera_1_1IPAModule.html#a872ccac8bdf3c6ebae395354e4bf9695":[7,0,0,73,8],
+"classlibcamera_1_1IPAModule.html#a8a092bd638e35b4d3f4ac51f58fe4d51":[6,0,0,74,4],
+"classlibcamera_1_1IPAModule.html#a8a092bd638e35b4d3f4ac51f58fe4d51":[7,0,0,73,4],
+"classlibcamera_1_1IPAModule.html#abf5eccedd5356d382c1377eddcaf7d9c":[6,0,0,74,0],
+"classlibcamera_1_1IPAModule.html#abf5eccedd5356d382c1377eddcaf7d9c":[7,0,0,73,0],
+"classlibcamera_1_1IPAModule.html#ac4442f2b5ae1e04e0ea0341848707670":[6,0,0,74,7],
+"classlibcamera_1_1IPAModule.html#ac4442f2b5ae1e04e0ea0341848707670":[7,0,0,73,7],
+"classlibcamera_1_1IPAModule.html#aeff066789ce1cfd94e14169cdcd6c7c7":[6,0,0,74,6],
+"classlibcamera_1_1IPAModule.html#aeff066789ce1cfd94e14169cdcd6c7c7":[7,0,0,73,6],
+"classlibcamera_1_1IPAModule.html#af14705dc1eebb33518e8c3aacf3b7957":[6,0,0,74,3],
+"classlibcamera_1_1IPAModule.html#af14705dc1eebb33518e8c3aacf3b7957":[7,0,0,73,3],
+"classlibcamera_1_1IPAModule.html#af70448b68ca0f671376b4ca93e402e79":[6,0,0,74,1],
+"classlibcamera_1_1IPAModule.html#af70448b68ca0f671376b4ca93e402e79":[7,0,0,73,1],
+"classlibcamera_1_1IPAProxy.html":[6,0,0,75],
+"classlibcamera_1_1IPAProxy.html":[7,0,0,74],
+"classlibcamera_1_1IPAProxy.html#a4d55ecad4864e4366622c1b804d2088a":[6,0,0,75,3],
+"classlibcamera_1_1IPAProxy.html#a4d55ecad4864e4366622c1b804d2088a":[7,0,0,74,3],
+"classlibcamera_1_1IPAProxy.html#a65233b120ff57bd960121bc37f9d86b5":[6,0,0,75,2],
+"classlibcamera_1_1IPAProxy.html#a65233b120ff57bd960121bc37f9d86b5":[7,0,0,74,2],
+"classlibcamera_1_1IPAProxy.html#a8986755718582d7960faa96f24777e93":[6,0,0,75,1],
+"classlibcamera_1_1IPAProxy.html#a8986755718582d7960faa96f24777e93":[7,0,0,74,1],
+"classlibcamera_1_1IPAProxy.html#aa298816d19d6455f64f3456ccaa70a98":[6,0,0,75,4],
+"classlibcamera_1_1IPAProxy.html#aa298816d19d6455f64f3456ccaa70a98":[7,0,0,74,4],
+"classlibcamera_1_1IPAProxy.html#ab5aa3b74285a5f4301218f05dd4cff09":[6,0,0,75,5],
+"classlibcamera_1_1IPAProxy.html#ab5aa3b74285a5f4301218f05dd4cff09":[7,0,0,74,5],
+"classlibcamera_1_1IPAProxy.html#ae59a8a916c5e244be8bdd6860503886f":[6,0,0,75,0],
+"classlibcamera_1_1IPAProxy.html#ae59a8a916c5e244be8bdd6860503886f":[7,0,0,74,0]
 };
