@@ -1,9 +1,7 @@
 var structlibcamera_1_1SwIspStats =
 [
     [ "Histogram", "structlibcamera_1_1SwIspStats.html#a0f7bf2f5c30750ca0a14373fe8f70969", null ],
-    [ "sumB_", "structlibcamera_1_1SwIspStats.html#a8f5c24249f09fce6b744adfde124f3c0", null ],
-    [ "sumG_", "structlibcamera_1_1SwIspStats.html#ae9de02e225bdf8e645ff223c59564ede", null ],
-    [ "sumR_", "structlibcamera_1_1SwIspStats.html#a5895eeeb9210ede00971326fab964c56", null ],
+    [ "sum_", "structlibcamera_1_1SwIspStats.html#afc233070f74c7135820c501cbd2f2310", null ],
     [ "valid", "structlibcamera_1_1SwIspStats.html#a05e639e8322155287ea5ffb9cb056c31", null ],
     [ "yHistogram", "structlibcamera_1_1SwIspStats.html#a873420e49e5b6aa4f544258f14467144", null ]
 ];
\ No newline at end of file
